'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var useMediaQuery = _interopDefault(require('@mui/material/useMediaQuery'));
var styles = require('@mui/material/styles');
var CssBaseline = _interopDefault(require('@mui/material/CssBaseline'));

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

var PaletteModeContext = /*#__PURE__*/React.createContext({
  toggleMode: function toggleMode() {}
});
var ThemeProvider = function ThemeProvider(_ref) {
  var children = _ref.children,
      createTheme = _ref.createTheme,
      initialMode = _ref.initialMode,
      onModeChange = _ref.onModeChange,
      _ref$cssBaseline = _ref.cssBaseline,
      cssBaseline = _ref$cssBaseline === void 0 ? true : _ref$cssBaseline;

  /** Find out preference for dark mode in operating system, either systemwide, or for a single user agent */
  var defaultMode = useMediaQuery('(prefers-color-scheme: dark)') ? 'dark' : 'light';

  var _useState = React.useState(initialMode || defaultMode),
      mode = _useState[0],
      setMode = _useState[1];

  var paletteModeContextValue = React.useMemo(function () {
    return {
      toggleMode: function toggleMode() {
        return setMode(function (prevMode) {
          return prevMode === 'light' ? 'dark' : 'light';
        });
      }
    };
  }, []);
  var theme = React.useMemo(function () {
    return createTheme(mode);
  }, [mode]);
  React.useEffect(function () {
    onModeChange && onModeChange(mode);
  }, [mode]);
  return React.createElement(PaletteModeContext.Provider, {
    value: paletteModeContextValue
  }, React.createElement(styles.ThemeProvider, {
    theme: theme
  }, cssBaseline && React.createElement(CssBaseline, null), children));
};
var useTheme = function useTheme() {
  var theme = styles.useTheme();

  var _React$useContext = React.useContext(PaletteModeContext),
      toggleMode = _React$useContext.toggleMode;

  return _extends({}, theme, {
    toggleMode: toggleMode
  });
};

exports.ThemeProvider = ThemeProvider;
exports.useTheme = useTheme;
//# sourceMappingURL=use-material-ui-theme.cjs.development.js.map
