import { useState, useMemo, useEffect, createElement, useContext, createContext } from 'react';
import useMediaQuery from '@mui/material/useMediaQuery';
import { ThemeProvider as ThemeProvider$1, useTheme as useTheme$1 } from '@mui/material/styles';
import CssBaseline from '@mui/material/CssBaseline';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

var PaletteModeContext = /*#__PURE__*/createContext({
  toggleMode: function toggleMode() {}
});
var ThemeProvider = function ThemeProvider(_ref) {
  var children = _ref.children,
      createTheme = _ref.createTheme,
      initialMode = _ref.initialMode,
      onModeChange = _ref.onModeChange,
      _ref$cssBaseline = _ref.cssBaseline,
      cssBaseline = _ref$cssBaseline === void 0 ? true : _ref$cssBaseline;

  /** Find out preference for dark mode in operating system, either systemwide, or for a single user agent */
  var defaultMode = useMediaQuery('(prefers-color-scheme: dark)') ? 'dark' : 'light';

  var _useState = useState(initialMode || defaultMode),
      mode = _useState[0],
      setMode = _useState[1];

  var paletteModeContextValue = useMemo(function () {
    return {
      toggleMode: function toggleMode() {
        return setMode(function (prevMode) {
          return prevMode === 'light' ? 'dark' : 'light';
        });
      }
    };
  }, []);
  var theme = useMemo(function () {
    return createTheme(mode);
  }, [mode]);
  useEffect(function () {
    onModeChange && onModeChange(mode);
  }, [mode]);
  return createElement(PaletteModeContext.Provider, {
    value: paletteModeContextValue
  }, createElement(ThemeProvider$1, {
    theme: theme
  }, cssBaseline && createElement(CssBaseline, null), children));
};
var useTheme = function useTheme() {
  var theme = useTheme$1();

  var _React$useContext = useContext(PaletteModeContext),
      toggleMode = _React$useContext.toggleMode;

  return _extends({}, theme, {
    toggleMode: toggleMode
  });
};

export { ThemeProvider, useTheme };
//# sourceMappingURL=use-material-ui-theme.esm.js.map
